@@ -1,8 +1,8 @@
 --- a/setup.py
 +++ b/setup.py
 @@ -8,6 +8,9 @@
- # Your cheese is so fresh most people think it's a cream: Mascarpone
  # ------------------------------
+ from __future__ import annotations
  
 +from sysconfig import get_platform
 +host_platform = get_platform()
@@ -10,7 +10,7 @@
  import os
  import re
  import shutil
-@@ -39,7 +42,7 @@ TIFF_ROOT = None
+@@ -42,7 +45,7 @@ TIFF_ROOT = None
  ZLIB_ROOT = None
  FUZZING_BUILD = "LIB_FUZZING_ENGINE" in os.environ
  
@@ -19,7 +19,7 @@
      import atexit
  
      atexit.register(
-@@ -151,7 +154,7 @@ def _find_library_dirs_ldconfig():
+@@ -154,7 +157,7 @@ def _find_library_dirs_ldconfig():
      # Based on ctypes.util from Python 2
  
      ldconfig = "ldconfig" if shutil.which("ldconfig") else "/sbin/ldconfig"
@@ -28,7 +28,7 @@
          if struct.calcsize("l") == 4:
              machine = os.uname()[4] + "-32"
          else:
-@@ -173,7 +176,7 @@ def _find_library_dirs_ldconfig():
+@@ -176,7 +179,7 @@ def _find_library_dirs_ldconfig():
          env["LC_ALL"] = "C"
          env["LANG"] = "C"
  
@@ -37,7 +37,7 @@
          args = [ldconfig, "-r"]
          expr = r".* => (.*)"
          env = {}
-@@ -430,6 +433,38 @@ class pil_build_ext(build_ext):
+@@ -442,6 +445,38 @@ class pil_build_ext(build_ext):
                  sdk_path = commandlinetools_sdk_path
          return sdk_path
  
@@ -76,7 +76,7 @@
      def build_extensions(self):
          library_dirs = []
          include_dirs = []
-@@ -512,7 +547,7 @@ class pil_build_ext(build_ext):
+@@ -524,7 +559,7 @@ class pil_build_ext(build_ext):
          if self.disable_platform_guessing:
              pass
  
@@ -85,7 +85,7 @@
              # pythonX.Y.dll.a is in the /usr/lib/pythonX.Y/config directory
              self.compiler.shared_lib_extension = ".dll.a"
              _add_directory(
-@@ -522,7 +557,7 @@ class pil_build_ext(build_ext):
+@@ -534,7 +569,7 @@ class pil_build_ext(build_ext):
                  ),
              )
  
@@ -94,9 +94,9 @@
              # attempt to make sure we pick freetype2 over other versions
              _add_directory(include_dirs, "/sw/include/freetype2")
              _add_directory(include_dirs, "/sw/lib/freetype2/include")
-@@ -570,13 +605,13 @@ class pil_build_ext(build_ext):
-                 _add_directory(library_dirs, os.path.join(sdk_path, "usr", "lib"))
-                 _add_directory(include_dirs, os.path.join(sdk_path, "usr", "include"))
+@@ -585,13 +620,13 @@ class pil_build_ext(build_ext):
+                 for extension in self.extensions:
+                     extension.extra_compile_args = ["-Wno-nullability-completeness"]
          elif (
 -            sys.platform.startswith("linux")
 -            or sys.platform.startswith("gnu")
@@ -112,7 +112,7 @@
                  # termux support for android.
                  # system libraries (zlib) are installed in /system/lib
                  # headers are at $PREFIX/include
-@@ -589,11 +624,11 @@ class pil_build_ext(build_ext):
+@@ -604,11 +639,11 @@ class pil_build_ext(build_ext):
                      ),
                  )
  
@@ -126,7 +126,7 @@
              _add_directory(library_dirs, "/opt/local/lib")
              _add_directory(include_dirs, "/opt/local/include")
  
-@@ -609,7 +644,7 @@ class pil_build_ext(build_ext):
+@@ -624,7 +659,7 @@ class pil_build_ext(build_ext):
              # alpine, at least
              _add_directory(library_dirs, "/lib")
  
@@ -135,7 +135,7 @@
              # on Windows, look for the OpenJPEG libraries in the location that
              # the official installer puts them
              program_files = os.environ.get("ProgramFiles", "")
-@@ -644,7 +679,7 @@ class pil_build_ext(build_ext):
+@@ -659,7 +694,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "zlib.h"):
                  if _find_library_file(self, "z"):
                      feature.zlib = "z"
@@ -144,7 +144,7 @@
                      feature.zlib = "zlib"  # alternative name
  
          if feature.want("jpeg"):
-@@ -652,7 +687,7 @@ class pil_build_ext(build_ext):
+@@ -667,7 +702,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "jpeglib.h"):
                  if _find_library_file(self, "jpeg"):
                      feature.jpeg = "jpeg"
@@ -153,7 +153,7 @@
                      feature.jpeg = "libjpeg"  # alternative name
  
          feature.openjpeg_version = None
-@@ -704,7 +739,7 @@ class pil_build_ext(build_ext):
+@@ -719,7 +754,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "tiff.h"):
                  if _find_library_file(self, "tiff"):
                      feature.tiff = "tiff"
@@ -162,7 +162,7 @@
                      self, "libtiff"
                  ):
                      feature.tiff = "libtiff"
-@@ -819,7 +854,7 @@ class pil_build_ext(build_ext):
+@@ -834,7 +869,7 @@ class pil_build_ext(build_ext):
          if feature.tiff:
              libs.append(feature.tiff)
              defs.append(("HAVE_LIBTIFF", None))
@@ -171,7 +171,7 @@
                  # This define needs to be defined if-and-only-if it was defined
                  # when compiling LibTIFF. LibTIFF doesn't expose it in `tiffconf.h`,
                  # so we have to guess; by default it is defined in all Windows builds.
-@@ -831,7 +866,7 @@ class pil_build_ext(build_ext):
+@@ -846,7 +881,7 @@ class pil_build_ext(build_ext):
          if feature.jpeg2000:
              libs.append(feature.jpeg2000)
              defs.append(("HAVE_OPENJPEG", None))
@@ -180,7 +180,7 @@
                  defs.append(("OPJ_STATIC", None))
          if feature.zlib:
              libs.append(feature.zlib)
-@@ -842,7 +877,7 @@ class pil_build_ext(build_ext):
+@@ -857,7 +892,7 @@ class pil_build_ext(build_ext):
          if feature.xcb:
              libs.append(feature.xcb)
              defs.append(("HAVE_XCB", None))
@@ -189,7 +189,7 @@
              libs.extend(["kernel32", "user32", "gdi32"])
          if struct.unpack("h", b"\0\1")[0] == 1:
              defs.append(("WORDS_BIGENDIAN", None))
-@@ -879,7 +914,7 @@ class pil_build_ext(build_ext):
+@@ -894,7 +929,7 @@ class pil_build_ext(build_ext):
  
          if feature.lcms:
              extra = []
@@ -198,7 +198,7 @@
                  extra.extend(["user32", "gdi32"])
              self._update_extension("PIL._imagingcms", [feature.lcms] + extra)
          else:
-@@ -898,7 +933,7 @@ class pil_build_ext(build_ext):
+@@ -913,7 +948,7 @@ class pil_build_ext(build_ext):
          else:
              self._remove_extension("PIL._webp")
  
@@ -207,7 +207,7 @@
          self._update_extension("PIL._imagingtk", tk_libs)
  
          build_ext.build_extensions(self)
-@@ -914,7 +949,7 @@ class pil_build_ext(build_ext):
+@@ -929,7 +964,7 @@ class pil_build_ext(build_ext):
          print("-" * 68)
          print(f"version      Pillow {PILLOW_VERSION}")
          v = sys.version.split("[")
